#
# spec file for package xfce4-verve-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define xfce_version 4.16.0
%define plugin verve
Name:           xfce4-%{plugin}-plugin
Version:        2.1.0
Release:        1.1
Summary:        Command Line Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-verve-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/2.1/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  meson >= 0.54.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libpcre2-8) >= 10.00
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{xfce_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{xfce_version}
BuildRequires:  pkgconfig(libxfce4util-1.0) >= %{xfce_version}
Requires:       xfce4-panel >= %{xfce_version}
# uses exo-open
Requires:       exo-tools
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Verve panel plugin is a command line plugin for the Xfce panel which
supports a command history, auto-completion, keyboard-shortcut focus grabbing and
opening URLs.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README.md THANKS
%license COPYING
%{_datadir}/xfce4/panel/plugins/xfce4-verve-plugin.desktop
%{_libdir}/xfce4/panel/plugins/libverve.so

%files lang -f %{name}.lang

%changelog
* Sun Jun 15 2025 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 2.1.0
  - Update README after switchover to meson
  - build: Automate copyright year management
  - Add meson build
  - Add about dialog
  - build: Remove unused verve-dbus-service code
  - Replace deprecated exo with libxfce4ui 4.21.0
  - Fix libxfce4panel include
* Mon Jan  6 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 2.0.4
  * Update copyright year
  * build: Bump dependency versions and fix deprecation warnings
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: Silence GCompletion deprecation warnings
  * I18n: Update po/LINGUAS list
  * build: Get rid of intltool
  * Translation Updates
* Sat Jul 15 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 2.0.3
  * Version number was not updated in 2.0.2, so let's go for 2.0.3
    now :/
- Update to version 2.0.2
  * Update copyright year
  * Fix critical when unblocking autohide
  * Revert "Fix critical when unblocking autohide"
  * Propagate the focus-out GtkEntry event
  * Refactor verve_spawn_command_line()
  * Fix g_thread_create_full deprecation
  * Fix GtkAlignment deprecations
  * Fix GtkMisc deprecations
  * Fix GtkColorButton deprecations
  * Fix XfceTitledDialog and GtkStock deprecations
  * Fix Gtk[HV]Box deprecations
  * Fix critical when unblocking autohide
  * Port to PCRE2 (#11)
  * Update `.gitignore`
  * Fix previous commit
  * build: Fix intltool lock file problem during make distcheck
  * build: Decrease make log level
  * build: Add GLib requirement
  * Update COPYING
  * Fix compilation warnings
  * autoconf: Some updates
  * Update `.gitignore`
  * Translation Updates
- Remove _service file
* Mon Dec 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.0.1
  * Fix build with panel 4.15
  * Modernize configure.ac.in
  * Fix xfce_rc_read_entry usage
  * Fix gdk_rgba_to_string usage
  * Fix GtkAdjustment usage
  * Fix GtkColorChooser usage
  * Fix GtkColorChooser usage
  * Fix GtkLabel usage
  * Fix GIOStream usage
  * Fix gtk_label_set_text call
  * Fix gtk_style_context_add_provider call
  * Fix discarded-qualifiers
  * Fix missing-prototypes
  * Remove GSourceFunc casts
  * Create README.md. Update configure.ac.in
  * Use GtkColorButton to pick foreground and background colors
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Jul 29 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Use %%license for COPYING
- Added bcond for git master builds
* Thu Apr 26 2018 seife+obs@b1-systems.com
- update to version 2.0.0
  * Switch from GTK2 to GTK3
  * DBUS support and verve-focus have been removed
  * allow to override the colors of the input area
  * Update translations
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to version 1.1.0
  - add ability to use xfce4-verve-plugin as a smartbookmark plugin
  - add ability to direct commands starting in ! or \ to DuckDuckGo
  - run commands through shell by default, to allow aliases,
    variables, etc.
  - use wordexp to expand directory names (when available), to
    allow variables, etc.
  - add an optional label on the left side of the plugin
  - expand properties window to configure the new features
  - increase maximum width of plugin
- do not package ChangeLog file, NEWS is enough
* Tue Jan 27 2015 gber@opensuse.org
- update to version 1.0.1
  - Use exo-open instead of the deprecated xfterm4 to launch
    commands in a term via ctrl-enter (bxo#9978)
  - Fix style when the entry loses focus (bxo#3525)
  - Build the plugin as a module
  - Port to libxfce4ui
  - Tons of translation updates
* Sun Apr 29 2012 gber@opensuse.org
- add dependency on exo-tools since exo-open is used
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Wed Apr  4 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
